%feature("docstring") OT::NegativeBinomialFactory
"Negative Binomial factory.

Notes
-----
We use the following estimator:

.. math::
    :nowrap:

    \\begin{eqnarray*}
      data : (\\vect{x}^1, \\hdots,\\vect{x}^n)\\\\
      \\displaystyle  \\hat{p}_n = \\frac{\\bar{x}_n}{\\hat{r}_n+\\bar{x}_n} \\\\
      \\displaystyle  \\hat{r}_n\\mbox{ solution of } n\\left(\\log\\left(\\frac{\\hat{r}_n}{\\hat{r}_n+\\bar{x}_n}\\right)-\\psi(\\hat{r}_n)\\right)+\\sum_{i=1}^n\\psi(x^i+\\hat{r}_n)=0\\\\
      \\mbox{The resolution is done using Brent's method.}
    \\end{eqnarray*}

See also
--------
DistributionFactory, NegativeBinomial"


// ---------------------------------------------------------------------

%feature("docstring") OT::NegativeBinomialFactory::buildAsNegativeBinomial
"Estimate the distribution as native distribution.

**Available usages**:

    buildAsNegativeBinomial()

    buildAsNegativeBinomial(*sample*)

    buildAsNegativeBinomial(*param*)

Parameters
----------
sample : 2-d sequence of float
    Data.
param : sequence of float
   The parameters of the :class:`~openturns.NegativeBinomial`.

Returns
-------
distribution : :class:`~openturns.NegativeBinomial`
    The estimated distribution as a NegativeBinomial.
    
    In the first usage, the default NegativeBinomial distribution is built."

